==> haskell-criterion-1.5.5.0-76-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.5.5.0
id: criterion-1.5.5.0-bERYKumzQf4c5qv4xODSy
key: criterion-1.5.5.0-bERYKumzQf4c5qv4xODSy
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
abi: f59f5df987db1836adc30e65f12d2a4c
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.5.5.0-bERYKumzQf4c5qv4xODSy
depends:
    Glob-0.10.0-ChBxYw8caZwGrFwUeslq31
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base-compat-batteries-0.10.5-4yGWfNAtoIR6ErVOgjlbM9 binary-0.8.6.0
    bytestring-0.10.8.2 cassava-0.5.2.0-8Du2Yyr9GN14usDmmst0N0
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs containers-0.6.0.1
    criterion-measurement-0.1.2.0-AfZif1szpgMBwtZ7orpyYK
    deepseq-1.4.4.0 directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-62uWe59Qc0n8ZRp4T9QEDh
    microstache-1.0.1.1-3PVojkzRnAGLYVxbsz2TRk mtl-2.2.2
    mwc-random-0.14.0.0-9OX8VYCuo08BrxmlBLXfTV
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 statistics-0.15.0.0-4HR8xF4hnXt7WRhsoLYDfz
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.5.5.0-80-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.5.5.0
id: criterion-1.5.5.0-29GPEmKThHa8Wryuntw4WR
key: criterion-1.5.5.0-29GPEmKThHa8Wryuntw4WR
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
abi: 4b660333ccd68e4f59dc7522cb04bef4
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
import-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/criterion-1.5.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-criterion
hs-libraries: HScriterion-1.5.5.0-29GPEmKThHa8Wryuntw4WR
depends:
    Glob-0.10.0-ChBxYw8caZwGrFwUeslq31
    aeson-1.4.6.0-6SSxkzo3COEI5l1mOYJmxL
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 base-4.12.0.0
    base-compat-batteries-0.10.5-4yGWfNAtoIR6ErVOgjlbM9 binary-0.8.6.0
    bytestring-0.10.8.2 cassava-0.5.2.0-8Du2Yyr9GN14usDmmst0N0
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs containers-0.6.0.1
    criterion-measurement-0.1.2.0-IE6iJIsF4QfAgu72jGJ6hg
    deepseq-1.4.4.0 directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    js-flot-0.8.3-LF7vQ1kAGl41Nl58RwjSyK
    js-jquery-3.3.1-AnEz8YN7BQAJj1Q6hAU0Am
    microstache-1.0.1.1-1imhJAaImAdLj05cS7ApJg mtl-2.2.2
    mwc-random-0.14.0.0-9OX8VYCuo08BrxmlBLXfTV
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    parsec-3.1.13.0 statistics-0.15.0.0-8Sw9Kl4JLkM5yO5q3mHaWn
    text-1.2.3.1 time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
